"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var core_1 = require("@angular/core");
var index_1 = require("../index");
var FilesService = (function () {
    function FilesService(baasicApp) {
        this.baasicApp = baasicApp;
    }
    /**
     * Returns a promise that is resolved once the find action has been performed. Success response returns a list of file resources matching the given criteria.
     * @method
     * @param options Query resource options object.
     * @returns A promise that is resolved once the find action has been performed.
     * @example FilesService.find({
                    pageNumber : 1,
                    pageSize : 10,
                    orderBy : '<field>',
                    orderDirection : '<asc|desc>',
                    search : '<search-phrase>'
                })
                .then(function (collection) {
                    // perform success action here
                },
                 function (response, status, headers, config) {
                     // perform error handling here
                });
     **/
    FilesService.prototype.find = function (options) {
        return this.baasicApp.fileModule.find(options);
    };
    /**
     * Returns a promise that is resolved once the get action has been performed. Success response returns requested file resource.
     * @method
     * @param id File id which uniquely identifies file resource that needs to be retrieved.
     * @param options Query resource options object.
     * @returns A promise that is resolved once the get action has been performed.
     * @example FilesService.get('<file-id>')
                    .then(function (data) {
                        // perform success action here
                    },
                     function (response, status, headers, config) {
                         // perform error handling here
                    });
     **/
    FilesService.prototype.get = function (id, options) {
        return this.baasicApp.fileModule.get(id, options);
    };
    /**
     * Returns a promise that is resolved once the update file action has been performed; this action will update a file resource if successfully completed. This route uses HAL enabled objects to obtain routes and therefore it doesn't apply `baasicFilesRouteDefinition` route template. Here is an example of how a route can be obtained from HAL enabled objects:
     * ```
     * let params = modelMapper.updateParams(fileEntry);
     * let uri = params['model'].links('put').href;
     * ```
     * @method
     * @param data A file entry object used to update specific file entry resource in the system.
     * @example // fileEntry is a file resource previously fetched using get action.
                    fileEntry.description = '<description>';
                    FilesService.update(fileEntry)
                        .then(function (data) {
                            // perform success action here
                        },
                         function (response, status, headers, config) {
                             // perform error handling here
                        });
     **/
    FilesService.prototype.update = function (data) {
        return this.baasicApp.fileModule.update(data);
    };
    /**
     * Returns a promise that is resolved once the unlink action has been performed. This action will remove one or many file resources from the system if successfully completed. If derived resource's format is passed, such as `width` and `height` for the image type of file resource, the operation will remove just derived resource. Otherwise, specified file and all its accompanying derived resources will be removed from the system. This route uses HAL enabled objects to obtain routes and therefore it doesn't apply baasicFilesRouteService route template. Here is an example of how a route can be obtained from HAL enabled objects:
     * ```
     * let params = modelMapper.removeParams(fileEntry);
     * let uri = params['model'].links('unlink').href;
     * ```
     * @method
     * @param data
     * @param options
     * @returns A promise that is resolved once the unlink action has been performed.
     * @example // fileEntry is a file resource previously fetched using get action. The following action will remove the original file resource and all accompanying derived file resources.
                    FilesService.unlink(fileEntry)
                        .then(function (data) {
                            // perform success action here
                        },
                         function (response, status, headers, config) {
                             // perform error handling here
                        });
                // fileEntry is a file resource previously fetched using get action. The following action will remove derived file resource only.
                    FilesService.unlink(fileEntry, {width: <width>, height: <height>})
                        .then(function (data) {
                            // perform success action here
                    },
                     function (response, status, headers, config) {
                         // perform error handling here
                    });
     **/
    FilesService.prototype.unlink = function (data, options) {
        return this.baasicApp.fileModule.unlink(data, options);
    };
    /**
     * Returns a promise that is resolved once the link action has been performed; this action links file resource from other modules into the Files module (For example: file resources from the Media Vault module can be linked directly into the Files module).
     * @method
     * @param data A file object that need to be inserted into the system.
     * @returns A promise that is resolved once the link action has been performed.
     * @example FilesService.link(fileObject)
                   .then(function (data) {
                       // perform success action here
                   },
                    function (response, status, headers, config) {
                        // perform error handling here
                   });
    **/
    FilesService.prototype.link = function (data) {
        return this.baasicApp.fileModule.link(data);
    };
    Object.defineProperty(FilesService.prototype, "batch", {
        get: function () {
            var baasicApp = this.baasicApp;
            return {
                /**
                 * Returns a promise that is resolved once the update action has been performed; this action updates specified file resources.
                 * @method
                 * @param data A collection of file objects used to update specified file resources.
                 * @returns A promise that is resolved once the update action has been performed.
                 * @example FilesService.batch.update(files)
                                .then(function (data) {
                                    // perform success action here
                                },
                                function (response, status, headers, config) {
                                    // perform error handling here
                                });
                **/
                update: function (data) {
                    return baasicApp.fileModule.batch.update(data);
                },
                /**
                 * Returns a promise that is resolved once the link action has been performed; this action links file resources from other modules into the Files module (For example: file resources from the Media Vault module can be linked directly into the Files module).
                 * @method
                 * @param data A collection of file objects that need to be inserted into the system.
                 * @returns A promise that is resolved once the link action has been performed.
                 * @example FilesService.batch.link(files)
                                .then(function (data) {
                                    // perform success action here
                                },
                                function (response, status, headers, config) {
                                    // perform error handling here
                                });
                **/
                link: function (data) {
                    return baasicApp.fileModule.batch.link(data);
                },
                /**
                 * Returns a promise that is resolved once the unlink action has been performed. This action will remove file resources from the system if successfully completed. If derived resource's format is passed, such as `width` and `height` for the image type of file resource, the operation will remove just derived resource. Otherwise, specified file and all its accompanying derived resources will be removed from the system.
                 * @method
                 * @param data Collection of file delete requests which uniquely identifies file resources that need to be deleted.
                 * @returns A promise that is resolved once the unlink action has been performed.
                 * @example // Remove original file resources
                                FilesService.batch.unlink([{ id: '<file-id>' }])
                                    .then(function (data) {
                                        // perform success action here
                                    },
                                    function (response, status, headers, config) {
                                        // perform error handling here
                                    });
                            // Remove derived file resources
                                FilesService.batch.unlink([{ id: '<file-id>', fileFormat: { width: <width>, height: <height> } }])
                                    .then(function (data) {
                                        // perform success action here
                                    },
                                    function (response, status, headers, config) {
                                        // perform error handling here
                                    });
                **/
                unlink: function (data) {
                    return baasicApp.fileModule.batch.unlink(data);
                }
            };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FilesService.prototype, "streams", {
        get: function () {
            var baasicApp = this.baasicApp;
            return {
                /**
                 * Returns a promise that is resolved once the get action has been performed. Success response returns the file stream if successfully completed. If derived resource's format is passed, such as `width` and `height` for the image type of file resource, the operation will return a stream of the derived resource. Otherwise, stream of the original file resource will be retrieved.
                 * @method
                 * @param id File id of the original file resource used to identify stream that needs to be retrieved from the system.
                 * @returns A promise that is resolved once the get action has been performed.
                 * @example // Request the original file stream
                                    FilesService.streams.get({id: '<path>'})
                                        .then(function (data) {
                                            // perform success action here
                                        },
                                        function (response, status, headers, config) {
                                            // perform error handling here
                                        });
                            // Request derived file stream
                                FilesService.streams.get({id: '<path>', width: <width>, height: <height>})
                                    .then(function (data) {
                                        // perform success action here
                                    },
                                    function (response, status, headers, config) {
                                        // perform error handling here
                                    });
                **/
                get: function (data) {
                    return baasicApp.fileModule.streams.get(data);
                },
                /**
                 * Returns a promise that is resolved once the get action has been performed. Success response returns the file stream as a blob. If derived resource's format is passed, such as `width` and `height` for the image type of file resource, the operation will return a blob of the derived file resource. Otherwise, blob of the original file resource will be retrieved. For more information on Blob objects please see [Blob Documentation](https://developer.mozilla.org/en-US/docs/Web/API/Blob).
                 * @method
                 * @example // Request the original blob
                                FilesService.streams.getBlob('<path>')
                                    .then(function (data) {
                                        // perform success action here
                                    },
                                    function (response, status, headers, config) {
                                        // perform error handling here
                                    });
                            // Request derived blob
                                FilesService.streams.getBlob({id: '<path>', width: <width>, height: <height>})
                                    .then(function (data) {
                                        // perform success action here
                                    },
                                    function (response, status, headers, config) {
                                        // perform error handling here
                                    });
                **/
                getBlob: function (data) {
                    return baasicApp.fileModule.streams.getBlob(data);
                },
                /**
                 * Returns a promise that is resolved once the update file stream action has been performed; this action will replace the existing stream with a new one. Alternatively, if a derived stream is being updated it will either create a new derived stream or replace the existing one. In order to update a derived stream, format needs to be passed (For example: `width` and `height` for the image type of file stream data type).
                 * @method
                 * @example // Update original file stream
                                FilesService.streams.update('<path>', <file-stream>)
                                    .then(function (data) {
                                        // perform success action here
                                    },
                                    function (response, status, headers, config) {
                                        // perform error handling here
                                    });
                            // Update derived file stream
                                FilesService.streams.update({id: '<path>', width: <width>, height: <height>}, <file-stream>)
                                    .then(function (data) {
                                        // perform success action here
                                    },
                                    function (response, status, headers, config) {
                                        // perform error handling here
                                    });
                **/
                update: function (data, stream) {
                    return baasicApp.fileModule.streams.update(data, stream);
                },
                /**
                 * Returns a promise that is resolved once the create file stream action has been performed; this action will upload the specified blob. For more information on Blob objects please see [Blob Documentation](https://developer.mozilla.org/en-US/docs/Web/API/Blob).
                 * @method
                 * @example FilesService.streams.create('<path>', <blob>)
                             .then(function (data) {
                                 // perform success action here
                             },
                                function (response, status, headers, config) {
                                    // perform error handling here
                            });
                **/
                create: function (data, stream) {
                    return baasicApp.fileModule.streams.create(data, stream);
                }
            };
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(FilesService.prototype, "acl", {
        get: function () {
            var baasicApp = this.baasicApp;
            return {
                /**
                 * Returns a promise that is resolved once the get action has been performed. Success response returns a list of ACL policies established for the specified file resource.
                 * @method
                 * @param options ACL options object.
                 * @returns A promise that is resolved once the get action has been performed.
                 * @example baasicFilesACLClient.get({id: '<file-id>'})
                                .then(function (data) {
                                    // perform success action here
                                },
                                function (response, status, headers, config) {
                                    // perform error handling here
                                });
                **/
                get: function (options) {
                    return baasicApp.fileModule.acl.get(options);
                },
                /**
                 * Returns a promise that is resolved once the update acl action has been performed, this action creates new ACL policy for the specified file resource.
                 * @method
                 * @param options An ACL policy object that needs to be inserted into the system. This object specifies parameters necessary for establishing user and/or role set of rights.
                 * @example let options = {id : '<file-id>'};
                            let aclObj =  {  actionId: '<action-id>',  roleId: '<role-id>',  userId: '<user-id>' };
                            options[baasicConstants.modelPropertyName] = aclObj;
                            baasicFilesACLClient.update(options)
                                .then(function (data) {
                                    // perform success action here
                                },
                                function (response, status, headers, config) {
                                    // perform error handling here
                                });
                **/
                update: function (options) {
                    return baasicApp.fileModule.acl.update(options);
                },
                /**
                 * Returns a promise that is resolved once the removeByUser action has been performed. This action deletes ACL policy assigned to the specified user and file resource.
                 * @method
                 * @param id File id which uniquely identifies file resource whose security privileges need to be retrieved and updated.
                 * @param action Action abbreviation which identifies ACL policy assigned to the specified user and file resource.
                 *               Supported Values:
                 *               "Create"
                 *               "Delete"
                 *               "Read"
                 *               "Update"
                 * @param user A value that uniquely identifies user for which ACL policy needs to be removed.
                 * @returns A promise that is resolved once the removeByUser action has been performed.
                 * @example baasicFilesACLClient.removeByUser('<file-id>', '<access-action>', '<username>')
                                .then(function (data) {
                                    // perform success action here
                                },
                                function (response, status, headers, config) {
                                    // perform error handling here
                                });
                **/
                removeByUser: function (id, action, user, data) {
                    return baasicApp.fileModule.acl.removeByUser(id, action, user, data);
                },
                /**
                 * Returns a promise that is resolved once the removeByRole action has been performed. This action deletes ACL policy assigned to the specified role and file resource.
                 * @method
                 * @example baasicFilesACLClient.removeByRole('<file-id>', '<access-action>', '<role-name>')
                                .then(function (data) {
                                    // perform success action here
                                },
                                function (response, status, headers, config) {
                                    // perform error handling here
                                });
                **/
                removeByRole: function (id, action, role, data) {
                    return baasicApp.fileModule.acl.removeByRole(id, action, role, data);
                }
            };
        },
        enumerable: true,
        configurable: true
    });
    return FilesService;
}());
FilesService = tslib_1.__decorate([
    core_1.Injectable(),
    tslib_1.__metadata("design:paramtypes", [index_1.BaasicAppService])
], FilesService);
exports.FilesService = FilesService;
