"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var core_1 = require("@angular/core");
var index_1 = require("../index");
var ValueSetService = (function () {
    function ValueSetService(baasicApp) {
        this.baasicApp = baasicApp;
    }
    /**
     * Returns a promise that is resolved once the find action has been performed. Success response returns a list of value set resources matching given criteria.
     * @param options query resource options object
     * @returns A promise that is resolved once the find action has beend performed.
     * @method
     * @example ValueSetService.find({
                    pageNumber: 1,
                    pageSize : 10,
                    orderBy : '<field>',
                    orderDirection : '<asc|desc>',
                    search : '<search-phrase>'
                })
                .then(function (collection) {
                    // perform success action here
                },
                 function (response, status, headers, config) {
                    // perform error handling here
                });
     **/
    ValueSetService.prototype.find = function (options) {
        return this.baasicApp.valueSetModule.find(options);
    };
    /**
     * Returns a promise that is resolved once the get action has been performed. Success response returns the specified value set resource.
     * @param setName value set name
     * @param options query resource options object
     * @returns A promise that is resolved once the get action has been performed.
     * @method
     * @example ValueSetService.get('<value-set-name>')
                   .success(function (data) {
                       // perform success action here
                   })
                   .error(function (response, status, headers, config) {
                       // perform error handling here
                   });
    **/
    ValueSetService.prototype.get = function (setName, options) {
        return this.baasicApp.valueSetModule.get(setName, options);
    };
    /**
     * Returns a promise that is resolved once the create value set action has been performed; this action creates a new value set resource.
     * @param data A key value object that needs to be inserted into the system.
     * @returns A promise that is resolved once the create value set action has beend performed.
     * @method
     * @example ValueSetService.create({
                    name: '<value-set-name>',
                    description: '<description>',
                    values: [{value: '<value>'}]
                })
                .then(function (data) {
                    // perform success action here
                },
                 function (response, status, headers, config) {
                    // perform error handling here
                });
     **/
    ValueSetService.prototype.create = function (data) {
        return this.baasicApp.valueSetModule.create(data);
    };
    /**
     * Returns a promise that is resolved once the update value set action has been performed; this action updates a value set resource. This route uses HAL enabled objects to obtain routes and therefore it doesn't apply `baasicValueSetService` route template. Here is an example of how a route can be obtained from HAL enabled objects:
     * ```
     * let params = modelMapper.removeParams(valueSet);
     * let uri = params['model'].links('put').href;
     * ```
     * @param data Value set object used to update specified value set resource.
     * @returns A promise that is resolved once the update value set action has been performed.
     * @method
     * @example // valueSet is a resource previously fetched using get action.
                        valueSet.name = '<new-name>';
                        ValueSetService.update(valueSet)
                            .then(function (data) {
                                // perform success action here
                            },
                             function (response, status, headers, config) {
                                // perform error handling here
                            });
     **/
    ValueSetService.prototype.update = function (data) {
        return this.baasicApp.valueSetModule.update(data);
    };
    /**
     * Returns a promise that is resolved once the remove action has been performed. This action will delete a value set resource if the action is completed successfully. This route uses HAL enabled objects to obtain routes and therefore it doesn't apply `baasicValueSetClient` route template. Here is an example of how a route can be obtained from HAL enabled objects:
     * ```
     * let params = modelMapper.removeParams(valueSet);
     * let uri = params['model'].links('delete').href;
     * ```
     * @param data A value set object used to delete specified value set resource.
     * @method
     * @example // valueSet is a resource previously fetched using get action.
                    valueSetService.remove(valueSet)
                        .then(function (data) {
                            // perform success action here
                        },
                         function (response, status, headers, config) {
                            // perform error handling here
                        });
     **/
    ValueSetService.prototype.remove = function (data) {
        return this.baasicApp.valueSetModule.remove(data);
    };
    Object.defineProperty(ValueSetService.prototype, "items", {
        get: function () {
            var baasicApp = this.baasicApp;
            return {
                /**
                * Returns a promise that is resolved once the find action has been performed. Success response returns a list of value set item resources matching given criteria.
                * @param options Query resource options object.
                * @returns A promise that is resolved once the find action has been performed.
                * @method items.find
                * @example ValueSetService.items.find({
                                setName: '<value-set-name>',
                                pageNumber : 1,
                                pageSize : 10,
                                orderBy : '<field>',
                                orderDirection : '<asc|desc>',
                                search : '<search-phrase>' })
                            .then(function (collection) {
                                // perform success action here
                            },
                            function (response, status, headers, config) {
                                // perform error handling here
                            });
                **/
                find: function (options) {
                    return baasicApp.valueSetModule.items.find(options);
                },
                /**
                * Returns a promise that is resolved once the get action has been performed. Success response returns the specified value set item resource.
                * @param setName value set name
                * @param id unique identifier of value set resource
                * @param options query resource options object
                * @returns A promise that is resolved once the get action has been performed.
                * @method items.get
                * @example ValueSetService.items.get('<value-set-name>', '<set-item-id>')
                            .then(function (data) {
                                   // perform success action here
                           },
                           function (response, status, headers, config) {
                               // perform error handling here
                           });
               **/
                get: function (setName, id, options) {
                    return baasicApp.valueSetModule.items.get(setName, id, options);
                },
                /**
                 * Returns a promise that is resolved once the create value set item action has been performed; this action creates a new value set item resource.
                 * @method
                 * @param data A value set item object that needs to be inserted into the system.
                 * @returns A promise that is resolved once the create value set item action has been performed.
                 * @example ValueSetService.items.create({
                                setId: '<value-set-id>',
                                value: '<value>'
                            })
                            .then(function (data) {
                                // perform success action here
                            },
                            function (response, status, headers, config) {
                                // perform error handling here
                            });
                **/
                create: function (data) {
                    return baasicApp.valueSetModule.items.create(data);
                },
                /**
                 * Returns a promise that is resolved once the update value set item action has been performed; this action updates a value set item resource. This route uses HAL enabled objects to obtain routes and therefore it doesn't apply `baasicValueSetClient` route template. Here is an example of how a route can be obtained from HAL enabled objects:
                 * ```
                 * let params = modelMapper.removeParams(valueSetItem);
                 * let uri = params['model'].links('put').href;
                 * ```
                 * @method
                 * @param data A value set item object used to update specified value set resource.
                 * @returns A promise that is resolved once the update value set item action has been performed.
                 * @example // valueSetItem is a resource previously fetched using get action.
                            valueSetItem.value = '<new-value>';
                            ValueSetItemService.items.update(valueSetItem)
                                .then(function (data) {
                                    // perform success action here
                                },
                                function (response, status, headers, config) {
                                    // perform error handling here
                                });
                **/
                update: function (data) {
                    return baasicApp.valueSetModule.items.update(data);
                },
                /**
                 * Returns a promise that is resolved once the remove action has been performed. This action will delete a value set item if the action is completed successfully. This route uses HAL enabled objects to obtain routes and therefore it doesn't apply `baasicValueSetClient` route template. Here is an example of how a route can be obtained from HAL enabled objects:
                 * ```
                 * let params = modelMapper.removeParams(valueSetItem);
                 * let uri = params['model'].links('delete').href;
                 * ```
                 * @param data A value set item object used to delete specified value set resource.
                 * @returns A promise that is resolved once the remove action has been performed.
                 * @method
                 * @example // valueSetItem is a resource previously fetched using get action.
                            ValueSetItemService.items.remove(valueSetItem)
                                .then(function (data) {
                                    // perform success action here
                                },
                                function (response, status, headers, config) {
                                    // perform error handling here
                                });
                **/
                remove: function (data) {
                    return baasicApp.valueSetModule.items.remove(data);
                }
            };
        },
        enumerable: true,
        configurable: true
    });
    return ValueSetService;
}());
ValueSetService = tslib_1.__decorate([
    core_1.Injectable(),
    tslib_1.__metadata("design:paramtypes", [index_1.BaasicAppService])
], ValueSetService);
exports.ValueSetService = ValueSetService;
